# Get Latest Trends from Twitter
[![Hit Count](http://hits.dwyl.io/sanjose/sanjose-twitter.svg)](http://hits.dwyl.io/sanjose/sanjose-twitter)
[![Build Status](https://travis-ci.org/josepipher/sanjose-twitter.svg?branch=master)](https://travis-ci.org/josepipher/sanjose-twitter)

## Prerequisite:
Prepare a **config.py** file in the working directory :

--------------------------------------------------------------------

These tokens are needed for user authentication.
Credentials can be generates via Twitter's Application Management:
	https://apps.twitter.com/app/new

consumer_key = "xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx"
consumer_secret = "xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx"
access_key = "xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx"
access_secret = "xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx"


To install,
```linux
pip install sanjose-twitter
```

To run command,
```linux
sanjose-twitter -h
```
